coef.lmm.rrpp: coef for lmm.rrpp model fits

View source: R/coef.lm.rrpp.r

coef.lmm.rrppR Documentation

coef for lmm.rrpp model fits

Description

The coef.lmm.rrpp function computes combined fixed and random effects by subject for lmm.rrpp model fits. This function does not operate the same as coef.lm.rrpp, for which coefficients and fixed effects are the same, and tests can be performed on fixed effects. It is merely a wrapper to combine the results of ranef.lmm.rrpp and fixef.lmm.rrpp.

Usage

## S3 method for class 'lmm.rrpp'
coef(object, type = c("matrix", "list"), ...)

Arguments

object

Object from lmm.rrpp

type

Whether to combine coefficients in a matrix or a list by variable.

...

Other arguments (currently none)

Author(s)

Michael Collyer


RRPP documentation built on July 7, 2026, 1:07 a.m.