mammalHRphy: Phylogenetic Data for the Mammal Home Range Data

mammalHRphyR Documentation

Phylogenetic Data for the Mammal Home Range Data

Description

Phylogenetic tree data that can be used along with mammalHR.

Details

A class phylo object containing data for the phylogenetic tree that pertains to the mammalHR data set. Although these data are not required for the generalized least squares (GLS) estimation example, used in the book, Permutational Biometry (Collyer & Adams, 2025), they provide additional graphical support for the example.

References

Collyer, M. L., & Adams D. C. (2025). Permutational Biometry: Volume 1, Univariate Data. Iowa State University Digital Press. NOT YET PUBLISHED.


RRPP documentation built on July 7, 2026, 1:07 a.m.