| coef.lmm.rrpp | R Documentation |
The coef.lmm.rrpp function computes
combined fixed and random effects by subject for
lmm.rrpp model fits. This function does not operate the same as
coef.lm.rrpp, for which coefficients and fixed effects are the same,
and tests can be performed on fixed effects. It is merely a wrapper to combine
the results of ranef.lmm.rrpp and fixef.lmm.rrpp.
## S3 method for class 'lmm.rrpp'
coef(object, type = c("matrix", "list"), ...)
object |
Object from |
type |
Whether to combine coefficients in a matrix or a list by variable. |
... |
Other arguments (currently none) |
Michael Collyer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.