| mammalHRphy | R Documentation |
Phylogenetic tree data that can be used along with
mammalHR.
A class phylo object containing data for the phylogenetic tree
that pertains to the mammalHR data set. Although these data are
not required for the generalized least squares (GLS)
estimation example, used in the book,
Permutational Biometry (Collyer & Adams, 2025), they provide additional
graphical support for the example.
Collyer, M. L., & Adams D. C. (2025). Permutational Biometry: Volume 1, Univariate Data. Iowa State University Digital Press. NOT YET PUBLISHED.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.